@@ -17,9 +17,11 @@
 # with logilab-database. If not, see <http://www.gnu.org/licenses/>.
 """logilab.database packaging information."""
 
+import sys
+
 distname = 'logilab-database'
 modname = 'database'
-numversion = (1, 13, 1)
+numversion = (1, 14, 1)
 version = '.'.join([str(num) for num in numversion])
 license = 'LGPL'
 
@@ -29,13 +31,26 @@ author_email = "contact@logilab.fr"
 description = "true unified database access"
 
 web = "http://www.logilab.org/project/%s" % distname
-ftp = "ftp://ftp.logilab.org/pub/%s" % modname
 mailinglist = "mailto://python-projects@lists.logilab.org"
 
 subpackage_of = 'logilab'
-subpackage_master = True
 
 install_requires = [
-    'logilab-common >= 0.55.2',
+    'setuptools',
+    'logilab-common >= 0.63.2',
     'six >= 1.4.0',
+    'Yapps2',
     ]
+
+tests_require = [
+    'psycopg2',
+    ]
+
+if sys.version_info[0] == 2:
+    tests_require.append('MySQL-python')
+
+classifiers = ["Topic :: Database",
+               "Programming Language :: Python",
+               "Programming Language :: Python :: 2",
+               "Programming Language :: Python :: 3",
+               ]
